lilypondfiletools.PaperBlock
============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock

.. autoclass:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.append
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.count
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.extend
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.index
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.insert
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.minimal_page_breaking
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.pop
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.remove
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.reverse
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.sort
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__add__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__contains__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__delitem__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__delslice__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__eq__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__format__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__ge__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__getitem__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__getslice__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__gt__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__iadd__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__imul__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__iter__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__le__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__len__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__lt__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__mul__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__ne__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__repr__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__reversed__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__rmul__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__setitem__
      ~abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__setslice__

Bases
-----

- :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock>`

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.is_formatted_when_empty
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.minimal_page_breaking
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.__setslice__
   :noindex:
